@@ -1,15 +1,21 @@
-# $Id: Util.pm 1828 2005-05-25 16:00:49Z btrott $
-
 package Crypt::DSA::Util;
+
 use strict;
+use Math::BigInt 1.78 try => 'GMP, Pari';
+use Crypt::URandom qw (urandom);
 
-use Math::BigInt lib => 'GMP';
 use Fcntl;
+use Carp qw( croak );
 
-use vars qw( @EXPORT_OK @ISA );
+our $VERSION = '1.19'; #VERSION
+
+use vars qw( $VERSION @ISA @EXPORT_OK );
 use Exporter;
-@EXPORT_OK = qw( bitsize bin2mp mp2bin mod_inverse mod_exp makerandom isprime );
-@ISA = qw( Exporter );
+
+BEGIN {
+    @ISA       = qw( Exporter );
+    @EXPORT_OK = qw( bitsize bin2mp mp2bin mod_inverse mod_exp makerandom isprime );
+}
 
 ## Nicked from Crypt::RSA::DataFormat.
 ## Copyright (c) 2001, Vipul Ved Prakash.
@@ -50,17 +56,7 @@ sub makerandom {
     my %param = @_;
     my $size = $param{Size};
     my $bytes = int($size / 8) + 1;
-    sysopen my $fh, '/dev/arandom', O_RDONLY
-        or return;
-    my($r, $read) = ('', 0);
-    while ($read < $bytes) {
-        my $got = sysread $fh, my($chunk), $bytes - $read;
-        next unless $got;
-        die "Error: $!" if $got == -1;
-        $r .= $chunk;
-        $read = length $r;
-    }
-    close $fh;
+    my $r = urandom($bytes);
     my $down = $size - 1;
     $r = unpack 'H*', pack 'B*', '0' x ( $size % 8 ? 8 - $size % 8 : 0 ) .
         '1' . unpack "b$down", $r;
